@@ -18,18 +18,19 @@
 
 mc.wbart <- function(
     x.train, y.train, x.test=matrix(0.0,0,0),
+    sparse=FALSE, a=0.5, b=1, augment=FALSE, rho=NULL,
+    xinfo=matrix(0.0,0,0), usequants=FALSE,
+    cont=FALSE, rm.const=TRUE,
     sigest=NA, sigdf=3, sigquant=0.90,
-    k=2.0,
-    power=2.0, base=.95,
-    sigmaf=NA,
-    lambda=NA,
+    k=2.0, power=2.0, base=.95,
+    sigmaf=NA, lambda=NA,
     fmean=mean(y.train),
     w=rep(1,length(y.train)),
     ntree=200L, numcut=100L,
     ndpost=1000L, nskip=100L,
     keepevery=1L, printevery=100L,
     keeptrainfits=TRUE, transposed=FALSE,
-    treesaslists=FALSE,
+    ##treesaslists=FALSE,
     mc.cores = 2L, nice = 19L,
     seed = 99L
     )
@@ -42,8 +43,15 @@ mc.wbart <- function(
     parallel::mc.reset.stream()
 
     if(!transposed) {
-        x.train <- t(x.train)
-        x.test <- t(x.test)
+        temp = bartModelMatrix(x.train, numcut, usequants=usequants,
+                               cont=cont, xinfo=xinfo, rm.const=rm.const)
+        x.train = t(temp$X)
+        numcut = temp$numcut
+        xinfo = temp$xinfo
+        if(length(x.test)>0)
+            x.test = t(bartModelMatrix(x.test[ , temp$rm.const]))
+        rm.const <- temp$rm.const
+        rm(temp)
     }
 
     mc.cores.detected <- detectCores()
@@ -58,13 +66,15 @@ mc.wbart <- function(
     for(i in 1:mc.cores) {
         parallel::mcparallel({psnice(value=nice);
                    wbart(x.train=x.train, y.train=y.train, x.test=x.test,
+                         sparse=sparse, a=a, b=b, augment=augment, rho=rho,
+                         xinfo=xinfo,
                          sigest=sigest, sigdf=sigdf, sigquant=sigquant,
                          k=k, power=power, base=base,
                          sigmaf=sigmaf, lambda=lambda, fmean=fmean, w=w,
                          ntree=ntree, numcut=numcut,
                          ndpost=mc.ndpost, nskip=nskip, keepevery=keepevery,
-                         printevery=printevery, transposed=TRUE,
-                         treesaslists=treesaslists)},
+                         printevery=printevery, transposed=TRUE)},
+                         ##treesaslists=treesaslists)},
                    silent=(i!=1))
                    ## to avoid duplication of output
                    ## capture stdout from first posterior only
@@ -83,7 +93,10 @@ mc.wbart <- function(
 
     if(mc.cores==1 | attr(post, 'class')!='wbart') return(post)
     else {
-        p <- nrow(x.train)
+        p <- nrow(x.train[ , post$rm.const])
+
+        ## if(length(rm.const)==0) rm.const <- 1:p
+        ## post$rm.const <- rm.const
 
         old.text <- paste0(as.character(mc.ndpost), ' ', as.character(ntree), ' ', as.character(p))
         old.stop <- nchar(old.text)
@@ -102,16 +115,19 @@ mc.wbart <- function(
             ## if(sigma.len>0)
             ##     post$sigma <- c(post$sigma, post.list[[i]]$sigma[sigma.beg:sigma.len])
 
-            post$sigma <- c(post$sigma, post.list[[i]]$sigma)
+            post$sigma <- cbind(post$sigma, post.list[[i]]$sigma)
 
             post$treedraws$trees <- paste0(post$treedraws$trees,
                                            substr(post.list[[i]]$treedraws$trees, old.stop+2,
                                                   nchar(post.list[[i]]$treedraws$trees)))
 
-            if(treesaslists) post$treedraws$lists <-
-                                 c(post$treedraws$lists, post.list[[i]]$treedraws$lists)
+            ## if(treesaslists) post$treedraws$lists <-
+            ##                      c(post$treedraws$lists, post.list[[i]]$treedraws$lists)
 
-            if(length(post$varcount)>0) post$varcount <- rbind(post$varcount, post.list[[i]]$varcount)
+            if(length(post$varcount)>0) {
+                post$varcount <- rbind(post$varcount, post.list[[i]]$varcount)
+                post$varprob <- rbind(post$varprob, post.list[[i]]$varprob)
+            }
         }
 
         if(length(post$yhat.train.mean)>0)
@@ -120,6 +136,11 @@ mc.wbart <- function(
         if(length(post$yhat.test.mean)>0)
             post$yhat.test.mean <- apply(post$yhat.test, 2, mean)
 
+        if(length(post$varcount)>0) {
+            post$varcount.mean <- apply(post$varcount, 2, mean)
+            post$varprob.mean <- apply(post$varprob, 2, mean)
+        }
+
         attr(post, 'class') <- 'wbart'
 
         return(post)
